@@ -1,6 +1,6 @@
 package Gtk3;
 {
-  $Gtk3::VERSION = '0.005';
+  $Gtk3::VERSION = '0.006';
 }
 
 use strict;
@@ -247,6 +247,15 @@ sub Gtk3::Button::new {
   }
 }
 
+sub Gtk3::CheckMenuItem::new {
+  my ($class, $mnemonic) = @_;
+  if (defined $mnemonic) {
+    return $class->new_with_mnemonic ($mnemonic);
+  }
+  return Glib::Object::Introspection->invoke (
+    $_GTK_BASENAME, 'CheckMenuItem', 'new', @_);
+}
+
 sub Gtk3::HBox::new {
   my ($class, $homogeneous, $spacing) = @_;
   $homogeneous = 5 unless defined $homogeneous;
@@ -255,6 +264,15 @@ sub Gtk3::HBox::new {
     $_GTK_BASENAME, 'HBox', 'new', $class, $homogeneous, $spacing);
 }
 
+sub Gtk3::ImageMenuItem::new {
+  my ($class, $mnemonic) = @_;
+  if (defined $mnemonic) {
+    return $class->new_with_mnemonic ($mnemonic);
+  }
+  return Glib::Object::Introspection->invoke (
+    $_GTK_BASENAME, 'ImageMenuItem', 'new', @_);
+}
+
 sub Gtk3::ListStore::new {
   return _common_tree_model_new ('ListStore', @_);
 }
@@ -295,6 +313,15 @@ sub Gtk3::Menu::popup_for_device {
     $menu, $device, $parent_menu_shell, $parent_menu_item, $real_func, $data, $button, $activate_time);
 }
 
+sub Gtk3::MenuItem::new {
+  my ($class, $mnemonic) = @_;
+  if (defined $mnemonic) {
+    return $class->new_with_mnemonic ($mnemonic);
+  }
+  return Glib::Object::Introspection->invoke (
+    $_GTK_BASENAME, 'MenuItem', 'new', @_);
+}
+
 sub Gtk3::MessageDialog::new {
   my ($class, $parent, $flags, $type, $buttons, $format, @args) = @_;
   my $dialog = Glib::Object::new ($class, message_type => $type,
